SimpleGauge

Struct SimpleGauge 

pub struct SimpleGauge {
    name: String,
    gauge: UpDownCounter<f64>,
    shadow: AtomicF64,
}
Represents a simple gauge with floating point values.

Fields

name: Stringgauge: UpDownCounter<f64>shadow: AtomicF64

Implementations

Source

impl SimpleGauge

pub fn new(name: &str, description: &str) -> MetricResult<Self>

Creates a new gauge with given name and description.

pub fn increment(&self, by: f64)

Increments the gauge by the given value.

pub fn decrement(&self, by: f64)

Decrements the gauge by the given value.

pub fn set(&self, value: f64)

Sets the gauge to the given value.

pub fn get(&self) -> f64

Retrieves the value of the gauge.

pub fn name(&self) -> String

Returns the name of the gauge given at construction.